==> elements-common-2.0.10-sources.jar: net/e6tech/elements/common/actor/pool/Worker.java <==
/*
 * Copyright 2017 Futeh Kao
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.e6tech.elements.common.actor.pool;

import akka.actor.AbstractActor;
import akka.actor.ActorRef;
import akka.actor.Status;
import scala.concurrent.ExecutionContext;

import java.util.concurrent.Callable;

/**
 * Created by futeh.
 */
public class Worker extends AbstractActor {

    private ActorRef pool;
    private ExecutionContext ec;

    public Worker(ActorRef pool) {
        this.pool = pool;
    }

    @Override
    public Receive createReceive() {
        return receiveBuilder()
                .match(Runnable.class, event -> {
                    try {
                        event.run();
                        getSender().tell(new Events.Response(), getSelf());
                    } catch (Throwable th) {
                        getSender().tell(new Status.Failure(th), getSelf());
                    } finally {
                        pool.tell(new Events.IdleWorker(getSelf()), getSelf());
                    }
                })
                .match(Callable.class, event -> {
                    try {
                        Object ret = event.call();
                        getSender().tell(new Events.Response(ret), getSelf());
                    } catch (Throwable th) {
                        getSender().tell(new Status.Failure(th), getSelf());
                    } finally {
                        pool.tell(new Events.IdleWorker(getSelf()), getSelf());
                    }
                })
                .build();
    }
}

==> elements-common-2.4.41-sources.jar: net/e6tech/elements/common/actor/pool/Worker.java <==
/*
 * Copyright 2017 Futeh Kao
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package net.e6tech.elements.common.actor.pool;

import akka.actor.AbstractActor;
import akka.actor.ActorRef;
import akka.actor.Status;

import java.util.concurrent.Callable;

/**
 * Created by futeh.
 */
public class Worker extends AbstractActor {

    private ActorRef pool;

    public Worker(ActorRef pool) {
        this.pool = pool;
    }

    @Override
    public Receive createReceive() {
        return receiveBuilder()
                .match(Runnable.class, event -> {
                    try {
                        event.run();
                        getSender().tell(new Events.Response(), getSelf());
                    } catch (Exception th) {
                        getSender().tell(new Status.Failure(th), getSelf());
                    } finally {
                        pool.tell(new Events.IdleWorker(getSelf()), getSelf());
                    }
                })
                .match(Callable.class, event -> {
                    try {
                        Object ret = event.call();
                        getSender().tell(new Events.Response(ret), getSelf());
                    } catch (Exception th) {
                        getSender().tell(new Status.Failure(th), getSelf());
                    } finally {
                        pool.tell(new Events.IdleWorker(getSelf()), getSelf());
                    }
                })
                .build();
    }
}
